@@ -46,7 +46,9 @@ def _create_aflw_aflwstats_game_model(
             dt = parse(line)
         elif "Round" in line:
             week = int(line.replace("Round", "").strip())
-        else:
+        elif "Final" in line:
+            pass
+        elif venue_name is None:
             venue_name = line
 
     team_urls = []
