@@ -648,6 +648,11 @@ class TestTeamModel(unittest.TestCase):
             fantasy_rating=None,
             second_chance_points=None,
             plus_minus=None,
+            set_one_points=None,
+            set_two_points=None,
+            set_three_points=None,
+            set_four_points=None,
+            set_five_points=None,
             version=VERSION,
         )
 
